@@ -12,17 +12,19 @@
 --
 */
 /* 
-   For (PC ?) Linux architecture.
+   Stack and Registers traversal for PC Linux.
+   Addresses decrease as the stack grows.
+   Registers are saved using SETJMP().
 */
 
-void mark_stack_and_registers(void) {
-  void**stack_pointer;
-  JMP_BUF stack_top;
-  (void)SETJMP(stack_top);
-  stack_pointer=((void**)(&stack_top));
-  /* Addresses decrease as the stack grows. */
-  for(; stack_pointer <= stack_bottom; stack_pointer++) {
-    gc_mark(*stack_pointer);
+void mark_stack_and_registers (void) {
+  void** max = stack_bottom + 8;
+  void** stack_pointer;
+  jmp_buf registers;
+
+  (void)setjmp(registers);
+  stack_pointer = ((void**)(&registers));
+  while (stack_pointer < max) {
+    gc_mark(*(stack_pointer++));
   }
 }
-
