@@ -4,7 +4,7 @@ void marking_loop(void){
   void**sp;
   void*stack_top={NULL,NULL};
   sp=stack_top;
-  for(;sp>=gc_root_main;sp--)
+  for(;sp>=stack_bottom;sp--)
     gc_mark(*sp);
 }
 
