@@ -17,16 +17,18 @@
    the flag -ansi of gcc (in file ${SmallEiffel}/sys/compiler.*).
 */
 
-void mark_loop(void){
-  void**stack_pointer;
-  void*stack_top[2]={NULL,NULL};
-  stack_pointer=stack_top;
+void mark_loop (void) {
+  void** max = stack_bottom + 11;
+  void** stack_pointer;
+  void* stack_top[2]={NULL,NULL};
+  stack_pointer = stack_top;
   /* Addresses decrease as the stack grows. */
-  for(; stack_pointer <= stack_bottom; stack_pointer++)
-    gc_mark(*stack_pointer);
+  while (stack_pointer < max) {
+    gc_mark(*(stack_pointer++));
+  }
 }
 
-void mark_stack_and_registers(void){
+void mark_stack_and_registers (void) {
   asm("	ta	0x3   ! ST_FLUSH_WINDOWS");
   mark_loop();
 }
