@@ -17,13 +17,15 @@
    objects are stored in the stack or in the jmpbuf of setjmp().
 */
 
-void mark_stack_and_registers(void){
-  void**stack_pointer;
+void mark_stack_and_registers (void) {
+  void** max = stack_bottom + 5; 
+  /* [4..1065] seems to be a valid range for MS C++ */
+  void** stack_pointer;
   jmp_buf stack_top;
+
   (void)setjmp(stack_top);
-  stack_pointer=((void**)(&stack_top));
-  for(; stack_pointer <= stack_bottom; stack_pointer++) {
-     gc_mark(*stack_pointer);
+  stack_pointer = ((void**)(&stack_top));
+  while (stack_pointer < max) {
+    gc_mark(*(stack_pointer++));
   }
 }
-
